@@ -50,9 +50,11 @@ if(scalar(@ARGV)<1){
 
 my %mappingdata;
 my $proteinorthotsvfile;
-	
+my $tsvout=0;
+
 for(my $argi=0;$argi<scalar(@ARGV);$argi++){
 	if($ARGV[$argi]=~m/\.tsv/){$proteinorthotsvfile=$ARGV[$argi];next;}
+	if($ARGV[$argi]=~m/--?tsv/){$tsvout=1;next;}
 	if($ARGV[$argi]=~m/proteinortho2html/){next;}
 	open(FILE,"<",$ARGV[$argi]);
 	while(<FILE>){
@@ -72,6 +74,8 @@ for(my $argi=0;$argi<scalar(@ARGV);$argi++){
 			$mappingdata{$1}=~s/^([A-Z][a-z]+ [a-z]+)//;
 			$mappingdata{$1}=~s/^([^ ]+ )([A-Z][a-z]+ [a-z]+)/$1/;
 		}
+		$mappingdata{$1}=~s/,/;/g;
+		$mappingdata{$1}=~s/[()]//g;
 	}
 	close(FILE);
 }
@@ -81,6 +85,28 @@ if(!-e $proteinorthotsvfile){
 	exit 1;
 }
 
+if($tsvout){
+	open(FILE,"<",$proteinorthotsvfile);
+	my $rowi=0;
+	while(<FILE>){
+		chomp;
+		if(/^#/){print "$_\n";next;}
+		my @arr=split("\t",$_);
+		print "$arr[0]\t$arr[1]\t$arr[2]";
+		for (my $i = 3; $i < scalar @arr; $i++) {
+			my @genes=split(",",$arr[$i]);
+			for (my $i = 0; $i < scalar @genes; $i++) {
+				if(exists $mappingdata{$genes[$i]}){
+					$genes[$i]="$mappingdata{$genes[$i]} ($genes[$i])";
+				}
+			}
+			print "\t".join(",",@genes);
+		}
+		print "\n";
+	}
+	exit 0;
+}
+
 #
 ## HEAD STUFF
 #
