@@ -15,6 +15,7 @@ my $po_file = $ARGV[0];
 my $cur_id = 0;
 
 my @species;
+my @species_num_prots;
 my $headerisset=0;
 my %protID2id;
 my $orthologygroup="";
@@ -115,6 +116,8 @@ if($po_file=~m/proteinortho-graph/){
 	    if(length($line)>0 && substr($line,0,1) ne "#"){ 
 	    	chomp($line);
 
+	    	if(!$headerisset){print STDERR "[ERROR] header is missing.\n";die}
+
 	   		my $curorthologygroup = ""; # create template orthology group
 
 	   		my @linesplt=split(/\t/,$line); # -> first 3 cols are number of species/genes and the algebraic connectivity of the given group
@@ -131,6 +134,7 @@ if($po_file=~m/proteinortho-graph/){
 
 					for(my $j = 0 ; $j < scalar(@linesplt2) ; $j=$j+1){
 
+						if( $linesplt2[$j] eq "*" ){next}
 						# $linesplt2[$j] is a protein (name like tr|A8JEJ4|A8JEJ4_CHLRE) of the current ortho group
 
 						if(!exists($protID2id{$i."#".$linesplt2[$j]})){ # map down to a integer A8JEJ4->0 ...
@@ -144,6 +148,8 @@ if($po_file=~m/proteinortho-graph/){
 						$protId=~s/^[sptr]{2}\|//g; # protein names can be 'sp|O08314|TGT_HELPY' -> 'O08314'
 						$protId=~s/\|[^|]+$//g; # protein names can be 'sp|O08314|TGT_HELPY' -> 'O08314'
 
+						if(scalar @species_num_prots != scalar @linesplt){ @species_num_prots=(0)x(scalar @linesplt) }
+						$species_num_prots[$i-3]++;
 						$species[$i-3].="\t\t\t\t".'<gene id="'.$protID2id{$i."#".$linesplt2[$j]}.'" protId="'.$protId."\"/>\n";
 						$curorthologygroup.="\t\t\t".'<geneRef id="'.$protID2id{$i."#".$linesplt2[$j]}."\"/>\n";
 					}
@@ -153,6 +159,7 @@ if($po_file=~m/proteinortho-graph/){
 	   			}
 	   		}
 	   		if($orthologygroup ne ""){$orthologygroup.="\n";}
+	   		if($con eq "NA"){$con="-1"}
 	   		$orthologygroup.="\t\t<orthologGroup id=\"$cur_id\">\n\t\t\t<score id=\"algcon\" value=\"$con\"/>\n".$curorthologygroup."\t\t</orthologGroup>";
 
 			$cur_id=$cur_id+1;
@@ -196,25 +203,30 @@ print "\n\t<notes>\n\t\tProteinortho OrthoXML file.\n\t</notes>\n";
 if($po_file=~m/proteinortho-graph/){
 	foreach my $cur_species (keys %species_graph){
 
-		print $species_graph{$cur_species}{"header"};
+		if(scalar keys %{$species_graph{$cur_species}} > 0){
 
-		foreach my $prot (keys %{$species_graph{$cur_species}}){
-			if($prot eq "header"){next;}
+			print $species_graph{$cur_species}{"header"};
 
-	   		my $prot_id = $prot;
+			foreach my $prot (keys %{$species_graph{$cur_species}}){
+				if($prot eq "header"){next;}
 
-			if($prot=~m/^[^\|]+\|([^\|]+)\|[^\|]+/){ # extract the true name (A8JEJ4)
-				$prot_id=$1;
+				my $prot_id = $prot;
+
+				if($prot=~m/^[^\|]+\|([^\|]+)\|[^\|]+/){ # extract the true name (A8JEJ4)
+					$prot_id=$1;
+				}
+
+				print "\t\t\t\t".'<gene id="'.$protID2id{$cur_species."#".$prot}.'" protId="'.$prot_id."\"/>\n";
 			}
 
-			print "\t\t\t\t".'<gene id="'.$protID2id{$cur_species."#".$prot}.'" protId="'.$prot_id."\"/>\n";
+			print "\t\t\t</genes>\n\t\t</database>\n\t</species>\n";
 		}
-
-		print "\t\t\t</genes>\n\t\t</database>\n\t</species>\n";
 	}
 }else{
-	foreach my $cur_species (@species){
-		print $cur_species."\t\t\t</genes>\n\t\t</database>\n\t</species>\n";
+	for (my $i = 0; $i < scalar @species; $i++) {
+		if($species_num_prots[$i]>0){
+			print $species[$i]."\t\t\t</genes>\n\t\t</database>\n\t</species>\n";
+		}
 	}
 }
 
