@@ -39,14 +39,15 @@
 
 use warnings;
 use strict;
+use Time::HiRes qw( time );
 
-if ( !$ARGV[0] or !$ARGV[1] ) {
-	print STDERR "Usage: perl proteinortho_do_mcl.pl CORES BLASTGRAPH1 (BLASTGRAPH2, ...)\n\nPerformes the mcl algorithm, given a sequence of blastgraphs (tab 6 format)\n";
+if ( scalar @ARGV <3 or !-e $ARGV[2] ) {
+	print STDERR "Usage: perl proteinortho_do_mcl.pl CORES INFLATION BLASTGRAPH...\n\nPerformes the mcl algorithm, given a sequence of blastgraphs (tab 6 format)\n";
 	exit;
 }
 
 my $cores = $ARGV[0];
-my $inflation = "20.0";
+my $inflation = $ARGV[1];
 
 sub Error {
 	print STDERR "\n[ERROR] ".$_[0]."\n";
@@ -63,15 +64,15 @@ if ($out =~ /mcl (.+)\n/) {
 }
 
 # the output file of mcl (gets deleted in the end)
-my $raw_mcl_output = $ARGV[1];
+my $raw_mcl_output = $ARGV[2];
 $raw_mcl_output .= 'mcltmp.proteinortho.mcl'; 
 
 # the .proteinortho-graph format (all blast edges that are in a cluster of mcl)
-my $outname_proteinorthograph = $ARGV[1];
+my $outname_proteinorthograph = $ARGV[2];
 $outname_proteinorthograph = 'mcl.proteinortho-graph';
 
 # the .proteinortho formatted output of mcl (with *, speciecounter, genecounter, ...)
-my $outname_proteinortho_FINAL = $ARGV[1];
+my $outname_proteinortho_FINAL = $ARGV[2];
 $outname_proteinortho_FINAL = 'mcl.proteinortho';
 
 my %speciesmap;
@@ -88,7 +89,7 @@ open(my $OF_proteinortho_FINAL, '>:encoding(UTF-8)',$outname_proteinortho_FINAL)
 
 	open(my $OF_tmpfilename, '>:encoding(UTF-8)', $tmpfilename) or die "Could not open temporary file $tmpfilename $!";
 
-		for (my $i = 1 ; $i < scalar(@ARGV) ; $i=$i+1) {
+		for (my $i = 2 ; $i < scalar(@ARGV) ; $i=$i+1) {
 			print STDERR "Preprocessing ".$ARGV[$i]."\n";
 
 			open(my $IF, '<:encoding(UTF-8)', $ARGV[$i])
@@ -131,9 +132,15 @@ close($OF_proteinortho_FINAL);
 # 2. run mcl
 #
 
-print STDERR "Running mcl ... \n";
+if($inflation >= 0){
 
-system('mcl '.$tmpfilename.' -I '.$inflation.' --abc -te '.$cores.' -o '.$raw_mcl_output.' 2>/dev/null');
+	print STDERR "Running mcl ... \n";
+	my $begin_time = time();
+	system('mcl '.$tmpfilename.' -I '.$inflation.' --abc -te '.$cores.' -o '.$raw_mcl_output.' 2>/dev/null');
+	my $end_time = time();
+	print STDERR "pure mcl runtime (seconds): ".($end_time - $begin_time)."\n";
+
+}
 
 unlink($tmpfilename); # remove input tmp file
 
@@ -207,7 +214,7 @@ open(my $OF_proteinorthograph, '>:encoding(UTF-8)',$outname_proteinorthograph) o
 	print $OF_proteinorthograph "# file_a	file_b\n# a	b	evalue_ab	bitscore_ab	evalue_ba	bitscore_ba\n";
 
 	# now go over the blast graphs and print all rows that are in a cluster (is_in_mclcluster)
-	for (my $i = 1 ; $i < scalar(@ARGV) ; $i=$i+1) {
+	for (my $i = 2 ; $i < scalar(@ARGV) ; $i=$i+1) {
 		print STDERR "Postprocessing ".$ARGV[$i]."\n";
 
 		open(my $IF, '<:encoding(UTF-8)', $ARGV[$i])
