@@ -193,6 +193,9 @@ for(my $v = 0 ; $v < scalar @ARGV ; $v++){
 	close($FHfasta);
 	if($cur_gene ne ""){$gene_len{$cur_gene}=$cur_len}
 }
+if(scalar %gene_len == 0){
+	print STDERR "[WARNING] I am missing the input fasta files, therefore I cannot compute the coverage and all outputs regarding the coverage are 0\n";
+}
 
 # foreach my $key (keys %gene_len){print STDERR "$key -> ".$gene_len{$key}."\n";}die;
 
@@ -290,10 +293,16 @@ if($step eq "2" || $step eq "none" || $step eq "all"){
 		{
 			#print STDERR join "\n", grep {my @a=split("\t",$_); scalar(@a)>10 && exists $gene_len{$a[1]}} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
 			#die;
+			if(scalar %gene_len == 0){
+				print STDERR "[WARNING] I am missing the input fasta files, therefore I cannot compute the coverage and all outputs regarding the coverage are 0\n";
+			}
 			my $num_a_all_blast_hits_filter=scalar grep {my @a=split("\t",$_); scalar(@a)>10 && exists $gene_len{$a[0]} && exists $gene_len{$a[1]} && $a[3]/$gene_len{$a[0]}>$cov/100 && $a[3]/$gene_len{$a[1]}>$cov/100} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
 			print STDERR "$num_a_all_blast_hits_filter/$num_a_all_blast_hits are covered enough (-cov=$cov).\n";
 		}
 		{
+			if(scalar %gene_len == 0){
+				print STDERR "[WARNING] I am missing the input fasta files, therefore I cannot compute the coverage and all outputs regarding the coverage are 0\n";
+			}
 			my $num_a_all_blast_hits_filter=scalar grep {my @a=split("\t",$_); scalar(@a)>10 && $a[10]<$evalue && exists $gene_len{$a[0]} && exists $gene_len{$a[1]} && $a[3]/$gene_len{$a[0]}>$cov/100 && $a[3]/$gene_len{$a[1]}>$cov/100} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
 			print STDERR "$num_a_all_blast_hits_filter/$num_a_all_blast_hits are significant and covered enough (combined).\n";
 		}
