@@ -50,7 +50,10 @@ foreach my $file (@ARGV) {
 		my $short_version = $file;
 		$short_version =~ s/^.*\///;
 		unless (defined($order{$short_version})) {
-			die("Species $file is not in the matrix\n");
+			$short_version=~s/_clean//g;
+			unless (defined($order{$short_version})) {
+				die("Species $file is not in the matrix\n");
+			}
 		}
 		$pos = $order{$short_version};		
 	}
@@ -59,9 +62,11 @@ foreach my $file (@ARGV) {
 	while(<FILE>) {
 		if ($_ =~ /^>([^\s]+)/) {
 			my $id = $1;
+			$id=~s/,/;/g; # proteinortho replaces comma with ; as the , is reserved in the proteinortho.tsv output format
 			if (exists($present{$id})) {next;}
 			if (exists($present{&convertUniprotAndNCBI($id)})) {next;} # mmseqs converts the ids automatically -> fix for -keep -p=mmseqsp
-			
+			$present{$id}=1;
+
 			# add to matrix
 			print "1\t1\t0";
 			for (my $i = 0; $i < scalar(keys %order); $i++) {
